==> ktorrent_5.1.0.orig.tar.xz: ktorrent-5.1.0/libktcore/util/indexofcompare.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef KT_INDEXOFCOMPARE_HH
#define KT_INDEXOFCOMPARE_HH

namespace kt
{
    template <class Container, class Item>
    struct IndexOfCompare
    {
        IndexOfCompare(Container* container) : container(container)
        {}

        bool operator()(Item* a, Item* b)
        {
            return container->indexOf(a) < container->indexOf(b);
        }

        Container* container;
    };
}

#endif

==> ktorrent_20.12.3.orig.tar.xz: ktorrent-20.12.3/libktcore/util/indexofcompare.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef KT_INDEXOFCOMPARE_HH
#define KT_INDEXOFCOMPARE_HH

namespace kt
{
template <class Container, class Item>
struct IndexOfCompare {
    IndexOfCompare(Container* container) : container(container)
    {}

    bool operator()(Item* a, Item* b)
    {
        return container->indexOf(a) < container->indexOf(b);
    }

    Container* container;
};
}

#endif
